@@ -1,7 +1,7 @@
 /*===========================================================================*
  * This file is part of the Abstract Library for Parallel Search (ALPS).     *
  *                                                                           *
- * ALPS is distributed under the Common Public License as part of the        *
+ * ALPS is distributed under the Eclipse Public License as part of the       *
  * COIN-OR repository (http://www.coin-or.org).                              *
  *                                                                           *
  * Authors:                                                                  *
@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2009, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2013, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include "Alps.h"
@@ -41,10 +41,10 @@ AlpsKnowledgeBroker::AlpsKnowledgeBroker()
     nodeProcessedNum_(0),
     nodeBranchedNum_(0),
     nodeDiscardedNum_(0),
+    nodePartialNum_(0),
     systemNodeProcessed_(0),
     nodeLeftNum_(0),
     treeDepth_(0),
-    bestSolDepth_(INT_MAX),
     bestSolNode_(-1),
     peakMemory_(0.0),
     exitStatus_(AlpsExitStatusUnknown),
